@@ -17,9 +17,8 @@ import string
 import types
 import uuid
 
-import six
-
 from django.core import validators
+from yaql import utils
 
 _LOCALIZABLE_KEYS = set(['label', 'help_text', 'error_messages'])
 
@@ -49,7 +48,7 @@ def decamelize(name):
 
 def explode(_string):
     """Explodes a string into a list of one-character strings."""
-    if not _string or not isinstance(_string, six.string_types):
+    if not _string or not isinstance(_string, basestring):
         return _string
     else:
         return list(_string)
@@ -78,14 +77,14 @@ def recursive_apply(predicate, transformer, value, *args):
     def rec(val):
         if predicate(val, *args):
             return rec(transformer(val, *args))
-        elif isinstance(val, dict):
-            return dict((rec(k), rec(v)) for (k, v) in six.iteritems(val))
-        elif isinstance(val, list):
+        elif isinstance(val, types.DictType):
+            return dict((rec(k), rec(v)) for (k, v) in val.iteritems())
+        elif isinstance(val, types.ListType):
             return [rec(v) for v in val]
-        elif isinstance(val, tuple):
+        elif isinstance(val, types.TupleType):
             return tuple([rec(v) for v in val])
         elif isinstance(val, types.GeneratorType):
-            return rec(val)
+            return rec(utils.limit(val))
         else:
             return val
 
@@ -108,9 +107,9 @@ def insert_hidden_ids(application):
             return rec(k), rec(v)
 
     def rec(val):
-        if isinstance(val, dict):
-            return dict(wrap(k, v) for k, v in six.iteritems(val))
-        elif isinstance(val, list):
+        if isinstance(val, types.DictType):
+            return dict(wrap(k, v) for k, v in val.iteritems())
+        elif isinstance(val, types.ListType):
             return [rec(v) for v in val]
         else:
             return val
@@ -119,13 +118,14 @@ def insert_hidden_ids(application):
 
 
 def int2base(x, base):
-    """Converts decimal integers to another number base from base-2 to base-36
+    """Converts decimal integers into another number base
+     from base-2 to base-36.
 
     :param x: decimal integer
     :param base: number base, max value is 36
     :return: integer converted to the specified base
     """
-    digs = string.digits + string.ascii_lowercase
+    digs = string.digits + string.lowercase
     if x < 0:
         sign = -1
     elif x == 0:
@@ -136,19 +136,8 @@ def int2base(x, base):
     digits = []
     while x:
         digits.append(digs[x % base])
-        x //= base
+        x /= base
     if sign < 0:
         digits.append('-')
     digits.reverse()
     return ''.join(digits)
-
-
-def to_str(text):
-    if not isinstance(text, str):
-        # unicode in python2
-        if isinstance(text, six.text_type):
-            text = text.encode('utf-8')
-        # bytes in python3
-        elif isinstance(text, six.binary_type):
-            text = text.decode('utf-8')
-    return text
