@@ -12,27 +12,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
 import json
+import logging
 
-from django.conf import settings
-from django.urls import reverse
+from django.core.urlresolvers import reverse
+from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
-
-from heat_dashboard.api import heat as heat_api
-
 from horizon import exceptions
 from horizon import tabs
-
+from openstack_dashboard.api import heat as heat_api
 from openstack_dashboard.api import nova as nova_api
-from openstack_dashboard import policy
+
 
 from muranoclient.common import exceptions as exc
-from muranodashboard.common import utils
 from muranodashboard.environments import api
 from muranodashboard.environments import consts
 from muranodashboard.environments import tables
 
+LOG = logging.getLogger(__name__)
+
 
 class OverviewTab(tabs.Tab):
     name = _("Component")
@@ -45,28 +43,26 @@ class OverviewTab(tabs.Tab):
         :param request:
         :return:
         """
-        def find_stack(name, **kwargs):
-            stacks, has_more, has_prev = heat_api.stacks_list(
-                request, sort_dir='asc', **kwargs)
+        def find_stack(name):
+            stacks, has_more, has_prev = heat_api.stacks_list(request)
             for stack in stacks:
                 if name in stack.stack_name:
                     stack_data = {'id': stack.id,
                                   'name': stack.stack_name}
                     return stack_data
             if has_more:
-                return find_stack(name, marker=stacks[-1].id)
+                find_stack()
             return {}
 
         def get_instance_and_stack(instance_data, request):
             instance_name = instance_data['name']
-            nova_openstackid = instance_data['openstackId']
             stack_name = ''
             instance_result_data = {}
             stack_result_data = {}
             instances, more = nova_api.server_list(request)
 
             for instance in instances:
-                if nova_openstackid in instance.id:
+                if instance_name in instance.name:
                     instance_result_data = {'name': instance.name,
                                             'id': instance.id}
                     stack_name = instance.name.split('-' + instance_name)[0]
@@ -83,10 +79,10 @@ class OverviewTab(tabs.Tab):
             if id == service_data['?']['status']:
                 status_name = name
 
-        detail_info = collections.OrderedDict([
+        detail_info = SortedDict([
             ('Name', getattr(service_data, 'name', '')),
             ('ID', service_data['?']['id']),
-            ('Type', tables.get_service_type(service_data) or 'Unknown'),
+            ('Type', service_data['?'][consts.DASHBOARD_ATTRS_KEY]['name']),
             ('Status', status_name), ])
 
         if hasattr(service_data, 'domain'):
@@ -104,8 +100,8 @@ class OverviewTab(tabs.Tab):
         if hasattr(service_data, 'floatingip'):
             detail_info['Floating IP'] = service_data.floatingip
 
-        # TODO(efedorova): Need to determine Instance subclass
-        # after it would be possible
+        #TODO(efedorova): Need to determine Instance subclass
+        #                 after it would be possible
         if hasattr(service_data,
                    'instance') and service_data['instance'] is not None:
                 instance, stack = get_instance_and_stack(
@@ -116,7 +112,7 @@ class OverviewTab(tabs.Tab):
                     detail_info['Stack'] = stack
 
         if hasattr(service_data,
-                   'instances') and service_data['instances'] is not None:
+                   'instances') and service_data['instance'] is not None:
                 instances_for_template = []
                 stacks_for_template = []
                 for instance in service_data['instances']:
@@ -154,16 +150,15 @@ class EnvLogsTab(tabs.Tab):
 
     def get_context_data(self, request):
         reports = self.tab_group.kwargs['logs']
-        for report in reports:
-            report.created = utils.adjust_datestr(request, report.created)
-        return {"reports": reports}
-
-
-class LatestLogsTab(EnvLogsTab):
-    name = _("Latest Deployment Log")
-
-    def allowed(self, request):
-        return self.data.get('reports')
+        lines = []
+        for r in reports:
+            line = format_log(r.created.replace('T', ' ') + ' - ' + r.text,
+                              r.level)
+            lines.append(line)
+        result = '\n'.join(lines)
+        if not result:
+            result = '\n'
+        return {"reports": result}
 
 
 class EnvConfigTab(tabs.TableTab):
@@ -209,7 +204,7 @@ class EnvironmentServicesTab(tabs.TableTab):
     def get_services_data(self):
         services = []
         self.environment_id = self.tab_group.kwargs['environment_id']
-        ns_url = "horizon:app-catalog:environments:index"
+        ns_url = "horizon:murano:environments:index"
         try:
             services = api.services_list(self.request, self.environment_id)
         except exc.HTTPForbidden:
@@ -227,13 +222,6 @@ class EnvironmentServicesTab(tabs.TableTab):
 
         return services
 
-    def get_context_data(self, request, **kwargs):
-        context = super(EnvironmentServicesTab,
-                        self).get_context_data(request, **kwargs)
-        context['MURANO_USE_GLARE'] = getattr(settings, 'MURANO_USE_GLARE',
-                                              False)
-        return context
-
 
 class DeploymentTab(tabs.TableTab):
     slug = "deployments"
@@ -242,13 +230,10 @@ class DeploymentTab(tabs.TableTab):
     template_name = 'horizon/common/_detail_table.html'
     preload = False
 
-    def allowed(self, request):
-        return policy.check((("murano", "list_deployments"),), request)
-
     def get_deployments_data(self):
         deployments = []
         self.environment_id = self.tab_group.kwargs['environment_id']
-        ns_url = "horizon:app-catalog:environments:index"
+        ns_url = "horizon:murano:environments:index"
         try:
             deployments = api.deployments_list(self.request,
                                                self.environment_id)
@@ -267,18 +252,24 @@ class DeploymentTab(tabs.TableTab):
 
 class EnvironmentDetailsTabs(tabs.TabGroup):
     slug = "environment_details"
-    tabs = (EnvironmentServicesTab, EnvironmentTopologyTab,
-            DeploymentTab, LatestLogsTab)
-    sticky = True
+    tabs = (EnvironmentServicesTab, EnvironmentTopologyTab, DeploymentTab)
 
 
 class ServicesTabs(tabs.TabGroup):
     slug = "services_details"
     tabs = (OverviewTab, ServiceLogsTab)
-    sticky = True
 
 
 class DeploymentDetailsTabs(tabs.TabGroup):
     slug = "deployment_details"
     tabs = (EnvConfigTab, EnvLogsTab,)
-    sticky = True
+
+
+def format_log(message, level):
+    if level == 'warning' or level == 'error':
+        frm = "<b><span style='color:#{0}' title='{1}'>{2}</span></b>"
+        return frm.format(consts.LOG_LEVEL_TO_COLOR[level],
+                          consts.LOG_LEVEL_TO_TEXT[level],
+                          message)
+    else:
+        return message
